==> jc-1.4.0.tar.gz: javax/swing/JMenu__24ActionChangedListener.h <==
// public class javax.swing.JMenu$ActionChangedListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 24d38e4b9f8feedd javax_swing_JMenu__24ActionChangedListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JMenu__24ActionChangedListener_H_
#define _JC_javax_swing_JMenu__24ActionChangedListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JMenu$object;
struct _jc_javax_swing_JMenuItem$object;

// Typedefs
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_refs	_jc_javax_swing_JMenu__24ActionChangedListener$sub_refs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs	_jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$refs	_jc_javax_swing_JMenu__24ActionChangedListener$refs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$nonrefs	_jc_javax_swing_JMenu__24ActionChangedListener$nonrefs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$object	_jc_javax_swing_JMenu__24ActionChangedListener$object;

typedef const struct _jc_javax_swing_JMenu__24ActionChangedListener$vmethods	_jc_javax_swing_JMenu__24ActionChangedListener$vmethods;
typedef const struct _jc_javax_swing_JMenu__24ActionChangedListener$vtable	_jc_javax_swing_JMenu__24ActionChangedListener$vtable;
typedef const struct _jc_javax_swing_JMenu__24ActionChangedListener$vtype	_jc_javax_swing_JMenu__24ActionChangedListener$vtype;

// Constructors
extern void _jc_javax_swing_JMenu__24ActionChangedListener$method$_init$a3bb497d05b7dd6c(_jc_env *, struct _jc_javax_swing_JMenu__24ActionChangedListener$object *, struct _jc_javax_swing_JMenu$object *, struct _jc_javax_swing_JMenuItem$object *);

// Virtual methods
extern void _jc_javax_swing_JMenu__24ActionChangedListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_JMenu__24ActionChangedListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenu__24ActionChangedListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_JMenu__24ActionChangedListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_JMenu__24ActionChangedListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_JMenu__24ActionChangedListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JMenu__24ActionChangedListener$vmethods	javax_swing_JMenu__24ActionChangedListener;
};

// Vtype
struct _jc_javax_swing_JMenu__24ActionChangedListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenu__24ActionChangedListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_refs {
	struct _jc_javax_swing_JMenuItem$object	*menuItem;
	struct _jc_javax_swing_JMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenu__24ActionChangedListener$refs {
    _jc_javax_swing_JMenu__24ActionChangedListener$sub_refs	javax_swing_JMenu__24ActionChangedListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenu__24ActionChangedListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs	javax_swing_JMenu__24ActionChangedListener;
};

// Object instance structure
struct _jc_javax_swing_JMenu__24ActionChangedListener$object {
	_jc_javax_swing_JMenu__24ActionChangedListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenu__24ActionChangedListener$vtype	*vtype;
	_jc_javax_swing_JMenu__24ActionChangedListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenu__24ActionChangedListener$vtype _jc_javax_swing_JMenu__24ActionChangedListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenu__24ActionChangedListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenu__24ActionChangedListener$class_object;

#endif	/* _JC_javax_swing_JMenu__24ActionChangedListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JMenu__24ActionChangedListener.h <==
// public class javax.swing.JMenu$ActionChangedListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 487d3b4937123e19 javax_swing_JMenu__24ActionChangedListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JMenu__24ActionChangedListener_H_
#define _JC_javax_swing_JMenu__24ActionChangedListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JMenu$object;
struct _jc_javax_swing_JMenuItem$object;

// Typedefs
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_refs	_jc_javax_swing_JMenu__24ActionChangedListener$sub_refs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs	_jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$refs	_jc_javax_swing_JMenu__24ActionChangedListener$refs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$nonrefs	_jc_javax_swing_JMenu__24ActionChangedListener$nonrefs;
typedef struct _jc_javax_swing_JMenu__24ActionChangedListener$object	_jc_javax_swing_JMenu__24ActionChangedListener$object;

typedef const struct _jc_javax_swing_JMenu__24ActionChangedListener$vmethods	_jc_javax_swing_JMenu__24ActionChangedListener$vmethods;
typedef const struct _jc_javax_swing_JMenu__24ActionChangedListener$vtable	_jc_javax_swing_JMenu__24ActionChangedListener$vtable;
typedef const struct _jc_javax_swing_JMenu__24ActionChangedListener$vtype	_jc_javax_swing_JMenu__24ActionChangedListener$vtype;

// Constructors
extern void _jc_javax_swing_JMenu__24ActionChangedListener$method$_init$a3bb497d05b7dd6c(_jc_env *, struct _jc_javax_swing_JMenu__24ActionChangedListener$object *, struct _jc_javax_swing_JMenu$object *, struct _jc_javax_swing_JMenuItem$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JMenu__24ActionChangedListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_JMenu__24ActionChangedListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenu__24ActionChangedListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_JMenu__24ActionChangedListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_JMenu__24ActionChangedListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JMenu__24ActionChangedListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JMenu__24ActionChangedListener$vmethods	javax_swing_JMenu__24ActionChangedListener;
};

// Vtype
struct _jc_javax_swing_JMenu__24ActionChangedListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenu__24ActionChangedListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_refs {
	struct _jc_javax_swing_JMenuItem$object	*menuItem;
	struct _jc_javax_swing_JMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenu__24ActionChangedListener$refs {
    _jc_javax_swing_JMenu__24ActionChangedListener$sub_refs	javax_swing_JMenu__24ActionChangedListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenu__24ActionChangedListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JMenu__24ActionChangedListener$sub_nonrefs	javax_swing_JMenu__24ActionChangedListener;
};

// Object instance structure
struct _jc_javax_swing_JMenu__24ActionChangedListener$object {
	_jc_javax_swing_JMenu__24ActionChangedListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenu__24ActionChangedListener$vtype	*vtype;
	_jc_javax_swing_JMenu__24ActionChangedListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenu__24ActionChangedListener$vtype _jc_javax_swing_JMenu__24ActionChangedListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenu__24ActionChangedListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenu__24ActionChangedListener$class_object;

#endif	/* _JC_javax_swing_JMenu__24ActionChangedListener_H_ */
